searchData={"items":[{"type":"module","title":"Iconify","doc":"Phoenix helpers for using 100,000+ SVG icons from 100+ icon sets compiled by [Iconify](https://icon-sets.iconify.design) (visit that site to browse the sets available and preview the icons)\n\nIt copies only the icons you use from the iconify library into your project, preparing them on-the-fly when you first use an icon in a view or component (either at compile time if using the Surface component, or on the first run during development).\n\nIt can be configured to embed the icons one of three ways:\n- `css` (default): generate a single CSS file containing SVGs of all the icons used \n- `img` (default for emojis): to create SVG files in your static assets, used to be included with `img` tags and loaded over HTTP (you may want to include [svg-inject](https://github.com/iconfu/svg-inject) on your site to enable styling of the SVGs, e.g. to change their colour)\n- `inline`: to generate a Phoenix Component for each icon used, used to embed the icons as `svg` tags inline in the HTML of your views (meaning the SVG will be included in LiveView diffs)\n- `set`: to generate an SVG sprite set for each family, and reference icons with a `use` tag inside of inline SVGs.\n\nThere is also an optional integration of [phoenix_live_favicon](https://github.com/BartOtten/phoenix_live_favicon) so you can set an icon (or emoji) as favicon on a page with `Iconify.maybe_set_favicon(socket, icon_name_or_emoji)`.","ref":"Iconify.html"},{"type":"module","title":"Installation - Iconify","doc":"```elixir\ndef deps do\n  [\n    {:iconify_ex, \"~> 0.1.0\"}\n  ]\nend\n```\n\nAfter running `mix deps.get` you need to fetch the latest [iconify icon sets](https://github.com/iconify/icon-sets) by running something like:\n```bash\ncd deps/iconify_ex/assets && yarn && cd -\n```","ref":"Iconify.html#module-installation"},{"type":"module","title":"Usage - Iconify","doc":"1. Add `import Iconify` in your Phoenix or LiveView module where you want to use it (or just once in the macros in your Web module). \n\n2. Set one of these options in config to choose which approach you want to use (see above for explanations):\n- `config :iconify_ex, :mode, :css` \n- `config :iconify_ex, :mode, :img` \n- `config :iconify_ex, :mode, :inline` \n- `config :iconify_ex, :mode, :set` \n\nIf using CSS mode, you'll need to include the CSS file in your layout (e.g. ` ` in your app's equivalent of `lib/my_app_web/components/layouts/root.html.heex`) and set some default styles that will be applied to all icons, by adding something like this to your app's main CSS (e.g. `assets/css/app.css`):\n```css\n[iconify] {\n  background-color: currentColor;\n  -webkit-mask-size: cover;\n  mask-size: cover;\n  min-width: 0.5rem;\n  min-height: 0.5rem;\n}\n```\n\nOther configurations include:\n\n```elixir\nconfig :iconify_ex, :fallback_icon, \"heroicons-solid:question-mark-circle\" # when an icon is not found\nconfig :iconify_ex, :generated_icon_modules_path, \"./lib/web/icons\" # for :inline mode\nconfig :iconify_ex, :generated_icon_static_path, \"./priv/static/images/icons\" # where CSS and images are stored\nconfig :iconify_ex, :generated_icon_static_url, \"/images/icons/\" # where CSS and images are served from\n```\n\n3. In all three cases, usage is the same (meaning you can easily switch between modes at any time) by including a component:\n\nEmbed an icon using default classes (copy the icon name from the [iconify website](https://icon-sets.iconify.design)):\n```html\n<.iconify icon=\"heroicons-solid:collection\" />\n```\n\nSpecify custom classes:\n```html\n<.iconify icon=\"heroicons-solid:collection\" class=\"w-8 h-8 text-base-content\" /> \n```\n\nOr if you use [Surface](https://surface-ui.org), it is highly recommended to use the macro component which means icons will be prepared at compile time rather than runtime:\n\nAdd `alias Iconify.Icon` to your Web module, and then:\n\n```html\n<#Icon iconify=\"heroicons-solid:collection\" />\n```\n\nIf your icon is dynamic, you'll still want to use the first form:\n```html\n<.iconify icon={@my_icon} />\n```\n\nNote: when using the CSS mode, there's sometimes a race condition that adds an icon several times. Until a fix is found you can run something like `sort -u -o icons_dir/icons.css icons_dir/icons.css` to clean up the CSS file.","ref":"Iconify.html#module-usage"},{"type":"function","title":"Iconify.add_icon_to_css/2","doc":"","ref":"Iconify.html#add_icon_to_css/2"},{"type":"function","title":"Iconify.complex?/1","doc":"Checks if the icon is part of a known emoji set or any set shouldn't use CSS mode (eg. includes color or animation).","ref":"Iconify.html#complex?/1"},{"type":"function","title":"Examples - Iconify.complex?/1","doc":"iex> Iconify.complex?(\"twemoji:smile\")\n    true\n    iex> Iconify.complex?(\"heroicons-solid:user\")\n    false","ref":"Iconify.html#complex?/1-examples"},{"type":"function","title":"Iconify.dev_env?/0","doc":"","ref":"Iconify.html#dev_env?/0"},{"type":"function","title":"Iconify.emoji?/1","doc":"Checks if the icon is part of a known emoji set","ref":"Iconify.html#emoji?/1"},{"type":"function","title":"Examples - Iconify.emoji?/1","doc":"iex> Iconify.emoji?(\"twemoji:smile\")\n    true\n    iex> Iconify.emoji?(\"heroicons-solid:user\")\n    false","ref":"Iconify.html#emoji?/1-examples"},{"type":"function","title":"Iconify.fallback_icon/0","doc":"Returns the fallback icon name.","ref":"Iconify.html#fallback_icon/0"},{"type":"function","title":"Examples - Iconify.fallback_icon/0","doc":"iex> Iconify.fallback_icon()\n    \"heroicons-solid:question-mark-circle\"","ref":"Iconify.html#fallback_icon/0-examples"},{"type":"function","title":"Iconify.generate_css_from_components/0","doc":"Generates CSS icons from existing components.","ref":"Iconify.html#generate_css_from_components/0"},{"type":"function","title":"Examples - Iconify.generate_css_from_components/0","doc":"iex> Iconify.generate_css_from_components()\n    :ok","ref":"Iconify.html#generate_css_from_components/0-examples"},{"type":"function","title":"Iconify.generate_css_from_static_files/0","doc":"Generates CSS icons from existing static files.","ref":"Iconify.html#generate_css_from_static_files/0"},{"type":"function","title":"Examples - Iconify.generate_css_from_static_files/0","doc":"iex> Iconify.generate_css_from_static_files()\n    :ok","ref":"Iconify.html#generate_css_from_static_files/0-examples"},{"type":"function","title":"Iconify.generate_sets_from_components/0","doc":"Generates icon sets from existing components.","ref":"Iconify.html#generate_sets_from_components/0"},{"type":"function","title":"Examples - Iconify.generate_sets_from_components/0","doc":"> Iconify.generate_sets_from_components()\n    [:ok, :ok, _]","ref":"Iconify.html#generate_sets_from_components/0-examples"},{"type":"function","title":"Iconify.iconify/1","doc":"Renders an icon as a `Phoenix.Component` based on the given assigns.","ref":"Iconify.html#iconify/1"},{"type":"function","title":"Examples - Iconify.iconify/1","doc":"iex> assigns = %{icon: \"heroicons-solid:user\", class: \"w-6 h-6\", __changed__: nil}\n    iex> Iconify.iconify(assigns) # Returns rendered icon HTML","ref":"Iconify.html#iconify/1-examples"},{"type":"function","title":"Iconify.list_all_existing/0","doc":"Lists all existing icons (components and CSS).","ref":"Iconify.html#list_all_existing/0"},{"type":"function","title":"Examples - Iconify.list_all_existing/0","doc":"> Iconify.list_all_existing()\n    %{\n      \"HeroiconsSolid\" => [Iconify.HeroiconsSolid.User, \"user\", _],\n      \"HeroiconsOutline\" => [Iconify.HeroiconsOutline.User, \"user\", _]\n    }","ref":"Iconify.html#list_all_existing/0-examples"},{"type":"function","title":"Iconify.list_components/0","doc":"Lists all available icon components.","ref":"Iconify.html#list_components/0"},{"type":"function","title":"Examples - Iconify.list_components/0","doc":"> Iconify.list_components()\n    %{\n      \"HeroiconsSolid\" => [Iconify.HeroiconsSolid.User, Iconify.HeroiconsSolid.Star, _],\n      \"HeroiconsOutline\" => [Iconify.HeroiconsOutline.User, Iconify.HeroiconsOutline.Star, _]\n    }","ref":"Iconify.html#list_components/0-examples"},{"type":"function","title":"Iconify.list_icons_in_css/0","doc":"Lists all icons defined in the CSS file.","ref":"Iconify.html#list_icons_in_css/0"},{"type":"function","title":"Examples - Iconify.list_icons_in_css/0","doc":"> Iconify.list_icons_in_css()\n    %{\n      \"HeroiconsSolid\" => [\"user\", \"star\", _],\n      \"HeroiconsOutline\" => [\"user\", \"star\", _]\n    }","ref":"Iconify.html#list_icons_in_css/0-examples"},{"type":"function","title":"Iconify.list_icons_in_images/0","doc":"","ref":"Iconify.html#list_icons_in_images/0"},{"type":"function","title":"Iconify.manual/2","doc":"Prepares and renders an icon.","ref":"Iconify.html#manual/2"},{"type":"function","title":"Examples - Iconify.manual/2","doc":"iex> %Phoenix.LiveView.Rendered{} = Iconify.manual(\"heroicons-solid:user\", mode: :css) # Returns rendered icon HTML or data","ref":"Iconify.html#manual/2-examples"},{"type":"function","title":"Iconify.maybe_phx_live_set_dynamic/3","doc":"","ref":"Iconify.html#maybe_phx_live_set_dynamic/3"},{"type":"function","title":"Iconify.maybe_set_favicon/2","doc":"Sets the favicon for a Phoenix LiveView socket.","ref":"Iconify.html#maybe_set_favicon/2"},{"type":"function","title":"Examples - Iconify.maybe_set_favicon/2","doc":"iex> socket = %Phoenix.LiveView.Socket{}\n    iex> %Phoenix.LiveView.Socket{} = Iconify.maybe_set_favicon(socket, \"heroicons-solid:star\")","ref":"Iconify.html#maybe_set_favicon/2-examples"},{"type":"function","title":"Iconify.path/0","doc":"Returns the configured path for generated icon modules.","ref":"Iconify.html#path/0"},{"type":"function","title":"Examples - Iconify.path/0","doc":"iex> Iconify.path()\n    \"./lib/web/icons\"","ref":"Iconify.html#path/0-examples"},{"type":"function","title":"Iconify.prepare/2","doc":"Prepares an icon based on the given assigns and mode (such as CSS, inline SVG, or image URL).","ref":"Iconify.html#prepare/2"},{"type":"function","title":"Examples - Iconify.prepare/2","doc":"iex> {:css, _function, %{icon: \"heroicons-solid:user\", class: \"w-4 h-4\", icon_name: \"heroicons-solid:user\"}} = Iconify.prepare(%{icon: \"heroicons-solid:user\", __changed__: nil}, :css)\n\n    iex> {:inline, _fun, %{icon: \"heroicons-solid:user\"}} = Iconify.prepare(%{icon: \"heroicons-solid:user\", __changed__: nil}, :inline)\n\n    iex> {:img, _fun, %{src: \"/images/icons/heroicons-solid/user.svg\"}} = Iconify.prepare(%{icon: \"heroicons-solid:user\", __changed__: nil}, :img)\n\n    iex> {:set, _fun, %{href: \"/images/icons/heroicons-solid.svg#user\"}} = Iconify.prepare(%{icon: \"heroicons-solid:user\", __changed__: nil}, :set)\n\n    iex> {:img, _fun, %{src: \"/images/icons/twemoji/rabbit.svg\"}} = Iconify.prepare(%{icon: \"twemoji:rabbit\", __changed__: nil})\n\n    iex> {:css, _fun, %{icon_name: \"heroicons-solid:question-mark-circle\"}} = Iconify.prepare(%{icon: \"non-existent-icon\", __changed__: nil})\n    \n     > Iconify.prepare(%{icon: \" ... \", __changed__: nil})\n    {:inline, _fun, %{icon: \" ... \"}}","ref":"Iconify.html#prepare/2-examples"},{"type":"function","title":"Iconify.prepare_entire_icon_family/2","doc":"Prepares an entire icon family for a particular mode.","ref":"Iconify.html#prepare_entire_icon_family/2"},{"type":"function","title":"Examples - Iconify.prepare_entire_icon_family/2","doc":"iex> Iconify.prepare_entire_icon_family(\"heroicons-solid\", :inline) # creates a Phoenix.Component module file for each icon in the set","ref":"Iconify.html#prepare_entire_icon_family/2-examples"},{"type":"function","title":"Iconify.static_path/0","doc":"Returns the configured path for generated static icon assets.","ref":"Iconify.html#static_path/0"},{"type":"function","title":"Examples - Iconify.static_path/0","doc":"iex> Iconify.static_path()\n    \"./priv/static/images/icons\"","ref":"Iconify.html#static_path/0-examples"},{"type":"function","title":"Iconify.static_url/0","doc":"Returns the configured URL for generated static icon assets.","ref":"Iconify.html#static_url/0"},{"type":"function","title":"Examples - Iconify.static_url/0","doc":"iex> Iconify.static_url()\n    \"/images/icons\"","ref":"Iconify.html#static_url/0-examples"},{"type":"function","title":"Iconify.using_svg_inject?/0","doc":"Checks if SVG injection is enabled in config.","ref":"Iconify.html#using_svg_inject?/0"},{"type":"function","title":"Examples - Iconify.using_svg_inject?/0","doc":"iex> Iconify.using_svg_inject?()\n    false","ref":"Iconify.html#using_svg_inject?/0-examples"},{"type":"module","title":"Iconify.Icon","doc":"A `Surface` component for rendering icons using various methods.","ref":"Iconify.Icon.html"},{"type":"module","title":"Specifying what icon to use - Iconify.Icon","doc":"- `iconify` or `icon`: Any icon from Iconify (https://icones.js.org)\n- `solid`: Shorthand for Heroicons solid icons\n- `outline`: Shorthand for Heroicons outline icons","ref":"Iconify.Icon.html#module-specifying-what-icon-to-use"},{"type":"module","title":"Extra Properties - Iconify.Icon","doc":"- `svg`: Optionally pass SVG markup directly\n- `mode`: Sets what rendering mode to use (see `Iconify` docs)\n- `class`: Any CSS classes to apply to the icon","ref":"Iconify.Icon.html#module-extra-properties"},{"type":"module","title":"Examples - Iconify.Icon","doc":"iex> alias Iconify.Icon\n    iex> ~F\"<#Icon iconify=\"heroicons-solid:user\" class=\"w-6 h-6\" />\"\n    # Returns rendered icon HTML\n\n    iex> ~F\"<#Icon solid=\"user\" class=\"w-6 h-6\" />\"\n          \n    iex> ~F\"<#Icon svg=\" ... \" class=\"w-6 h-6\" />\"","ref":"Iconify.Icon.html#module-examples"},{"type":"module","title":"Properties - Iconify.Icon","doc":"* **iconify** *:string, required: false, static: true*\n* **icon** *:string, required: false, static: true*\n* **solid** *:string, required: false, static: true*\n* **outline** *:string, required: false, static: true*\n* **svg** *:string, default: nil, required: false, static: true*\n* **mode** *:atom, required: false, static: true*\n* **class** *:css_class, default: nil*","ref":"Iconify.Icon.html#module-properties"},{"type":"function","title":"Iconify.Icon.class_to_string/1","doc":"","ref":"Iconify.Icon.html#class_to_string/1"},{"type":"function","title":"Iconify.Icon.expand/3","doc":"","ref":"Iconify.Icon.html#expand/3"},{"type":"macro","title":"Iconify.Icon.icon_name/1","doc":"","ref":"Iconify.Icon.html#icon_name/1"},{"type":"extras","title":"Iconify for Phoenix","doc":"# Iconify for Phoenix\n\nPhoenix helpers for using 100,000+ SVG icons from 100+ icon sets compiled by [Iconify](https://icon-sets.iconify.design) (visit that site to browse the sets available and preview the icons)\n\nIt copies only the icons you use from the iconify library into your project, preparing them on-the-fly when you first use an icon in a view or component (either at compile time if using the Surface component, or on the first run during development).\n\nIt can be configured to embed the icons one of three ways:\n- `css` (default): generate a single CSS file containing SVGs of all the icons used \n- `img` (default for emojis): to create SVG files in your static assets, used to be included with `img` tags and loaded over HTTP (you may want to include [svg-inject](https://github.com/iconfu/svg-inject) on your site to enable styling of the SVGs, e.g. to change their colour)\n- `inline`: to generate a Phoenix Component for each icon used, used to embed the icons as `svg` tags inline in the HTML of your views (meaning the SVG will be included in LiveView diffs)\n- `set`: to generate an SVG sprite set for each family, and reference icons with a `use` tag inside of inline SVGs.\n\nThere is also an optional integration of [phoenix_live_favicon](https://github.com/BartOtten/phoenix_live_favicon) so you can set an icon (or emoji) as favicon on a page with `Iconify.maybe_set_favicon(socket, icon_name_or_emoji)`.","ref":"readme.html"},{"type":"extras","title":"Installation - Iconify for Phoenix","doc":"```elixir\ndef deps do\n  [\n    {:iconify_ex, \"~> 0.1.0\"}\n  ]\nend\n```\n\nAfter running `mix deps.get` you need to fetch the latest [iconify icon sets](https://github.com/iconify/icon-sets) by running something like:\n```bash\ncd deps/iconify_ex/assets && yarn && cd -\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Iconify for Phoenix","doc":"1. Add `import Iconify` in your Phoenix or LiveView module where you want to use it (or just once in the macros in your Web module). \n\n2. Set one of these options in config to choose which approach you want to use (see above for explanations):\n- `config :iconify_ex, :mode, :css` \n- `config :iconify_ex, :mode, :img` \n- `config :iconify_ex, :mode, :inline` \n- `config :iconify_ex, :mode, :set` \n\nIf using CSS mode, you'll need to include the CSS file in your layout (e.g. ` ` in your app's equivalent of `lib/my_app_web/components/layouts/root.html.heex`) and set some default styles that will be applied to all icons, by adding something like this to your app's main CSS (e.g. `assets/css/app.css`):\n```css\n[iconify] {\n  background-color: currentColor;\n  -webkit-mask-size: cover;\n  mask-size: cover;\n  min-width: 0.5rem;\n  min-height: 0.5rem;\n}\n```\n\nOther configurations include:\n\n```elixir\nconfig :iconify_ex, :fallback_icon, \"heroicons-solid:question-mark-circle\" # when an icon is not found\nconfig :iconify_ex, :generated_icon_modules_path, \"./lib/web/icons\" # for :inline mode\nconfig :iconify_ex, :generated_icon_static_path, \"./priv/static/images/icons\" # where CSS and images are stored\nconfig :iconify_ex, :generated_icon_static_url, \"/images/icons/\" # where CSS and images are served from\n```\n\n3. In all three cases, usage is the same (meaning you can easily switch between modes at any time) by including a component:\n\nEmbed an icon using default classes (copy the icon name from the [iconify website](https://icon-sets.iconify.design)):\n```html\n<.iconify icon=\"heroicons-solid:collection\" />\n```\n\nSpecify custom classes:\n```html\n<.iconify icon=\"heroicons-solid:collection\" class=\"w-8 h-8 text-base-content\" /> \n```\n\nOr if you use [Surface](https://surface-ui.org), it is highly recommended to use the macro component which means icons will be prepared at compile time rather than runtime:\n\nAdd `alias Iconify.Icon` to your Web module, and then:\n\n```html\n<#Icon iconify=\"heroicons-solid:collection\" />\n```\n\nIf your icon is dynamic, you'll still want to use the first form:\n```html\n<.iconify icon={@my_icon} />\n```\n\nNote: when using the CSS mode, there's sometimes a race condition that adds an icon several times. Until a fix is found you can run something like `sort -u -o icons_dir/icons.css icons_dir/icons.css` to clean up the CSS file.","ref":"readme.html#usage"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}